@@ -1,11 +1,12 @@
 use crate::result::LineResult;
-use colored::*;
+use owo_colors::AnsiColors::{Red, Yellow};
+use owo_colors::OwoColorize;
 use std::fmt::Write;
 
 pub(crate) fn diff_line_result(line: &LineResult) -> String {
-    let mut err_color = "red";
+    let mut err_color = Red;
     if line.severity.is_warning() {
-        err_color = "yellow"
+        err_color = Yellow;
     }
 
     diff_lines_with_err_color(line.old.trim(), line.new.trim(), err_color)
@@ -13,14 +14,18 @@ pub(crate) fn diff_line_result(line: &LineResult) -> String {
 
 #[allow(dead_code)]
 pub(crate) fn diff_lines(old_str: &str, new_str: &str) -> String {
-    diff_lines_with_err_color(old_str, new_str, "red")
+    diff_lines_with_err_color(old_str, new_str, Red)
 }
 
 // Screenshot:
 // https://raw.githubusercontent.com/johannhof/difference.rs/master/assets/github-style.png
 // https://github.com/johannhof/difference.rs/blob/master/examples/github-style.rs
 #[allow(unused_must_use)]
-pub(crate) fn diff_lines_with_err_color(old_str: &str, new_str: &str, err_color: &str) -> String {
+pub(crate) fn diff_lines_with_err_color(
+    old_str: &str,
+    new_str: &str,
+    err_color: owo_colors::AnsiColors,
+) -> String {
     let diffs = diff::lines(old_str, new_str);
 
     let mut out = String::new();
@@ -34,7 +39,7 @@ pub(crate) fn diff_lines_with_err_color(old_str: &str, new_str: &str, err_color:
             diff::Result::Left(x) => {
                 match diffs.get(i + 1) {
                     Some(diff::Result::Right(y)) => {
-                        write!(out, "{}", "-".color(err_color));
+                        write!(out, "{}", "-".color(Red));
                         let sub_diffs = diff::chars(y, x);
                         for c in sub_diffs {
                             match c {
